<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Nem todos os calendários estão completamente em cache.",
"Everything seems to be completely cached" => "Parece que tudo foi cacheado",
"No calendars found." => "Nenhum calendário encontrado.",
"No events found." => "Nenhum evento encontrado.",
"Wrong calendar" => "Calendário incorreto",
"You do not have the permissions to edit this event." => "Você não tem permissões para editar esse evento.",
"The file contained either no events or all events are already saved in your calendar." => "O arquivo não continha nenhum evento ou todos os eventos já estão guardados no seu calendário.",
"events has been saved in the new calendar" => "os eventos foram salvos no novo calendário",
"Import failed" => "Falha na importação",
"events has been saved in your calendar" => "os eventos foram salvos em seu calendário",
"New Timezone:" => "Novo fuso horário",
"Timezone changed" => "Fuso horário alterado",
"Invalid request" => "Pedido inválido",
"Calendar" => "Calendário",
"Deletion failed" => "Remoção falhou",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"user" => "usuário",
"group" => "grupo",
"Editable" => "Editável",
"Shareable" => "Compartilhável",
"Deletable" => "Removível",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Domingo",
"Monday" => "Segunda-feira",
"Tuesday" => "Terça-feira",
"Wednesday" => "Quarta-feira",
"Thursday" => "Quinta-feira",
"Friday" => "Sexta-feira",
"Saturday" => "Sábado",
"Sun." => "Dom.",
"Mon." => "Seg.",
"Tue." => "Ter.",
"Wed." => "Qua.",
"Thu." => "Qui.",
"Fri." => "Sex.",
"Sat." => "Sáb.",
"January" => "Janeiro",
"February" => "Fevereiro",
"March" => "Março",
"April" => "Abril",
"May" => "Maio",
"June" => "Junho",
"July" => "Julho",
"August" => "Agosto",
"September" => "Setembro",
"October" => "Outubro",
"November" => "Novembro",
"December" => "Dezembro",
"Jan." => "Jan.",
"Feb." => "Fev.",
"Mar." => "Mar.",
"Apr." => "Abr.",
"May." => "Mai.",
"Jun." => "Jun.",
"Jul." => "Jul.",
"Aug." => "Ago.",
"Sep." => "Set.",
"Oct." => "Out.",
"Nov." => "Nov.",
"Dec." => "Dez.",
"All day" => "Todo o dia",
"New Calendar" => "Novo Calendário",
"Missing or invalid fields" => "Campos faltando ou inválidos",
"Title" => "Título",
"From Date" => "Desde a Data",
"From Time" => "Desde a Hora",
"To Date" => "Até a Data",
"To Time" => "Até a Hora",
"The event ends before it starts" => "O evento termina antes de começar",
"There was a database fail" => "Houve uma falha de banco de dados",
"Birthday" => "Aniversário",
"Business" => "Negócio",
"Call" => "Chamada",
"Clients" => "Clientes",
"Deliverer" => "Entrega",
"Holidays" => "Feriados",
"Ideas" => "Idéias",
"Journey" => "Jornada",
"Jubilee" => "Jubileu",
"Meeting" => "Reunião",
"Other" => "Outros",
"Personal" => "Pessoal",
"Projects" => "Projetos",
"Questions" => "Perguntas",
"Work" => "Trabalho",
"by" => "por",
"unnamed" => "sem nome",
"You do not have the permissions to update this calendar." => "Você não tem permissões para atualizar esse calendário.",
"You do not have the permissions to delete this calendar." => "Você não tem permissões para remover esse calendário.",
"You do not have the permissions to add to this calendar." => "Você não tem permissões para adicionar esse calendário.",
"You do not have the permissions to add events to this calendar." => "Você não tem permissões para adicionar eventos nesse calendário.",
"You do not have the permissions to delete this event." => "Você não tem permissões para remover esse evento.",
"Busy" => "Ocupado",
"Public" => "Público",
"Private" => "Privado",
"Confidential" => "Confidencial",
"Does not repeat" => "Não repetir",
"Daily" => "Diariamente",
"Weekly" => "Semanal",
"Every Weekday" => "Cada dia da semana",
"Bi-Weekly" => "De duas em duas semanas",
"Monthly" => "Mensal",
"Yearly" => "Anual",
"never" => "nunca",
"by occurrences" => "por ocorrências",
"by date" => "por data",
"by monthday" => "por dia do mês",
"by weekday" => "por dia da semana",
"events week of month" => "semana do evento no mês",
"first" => "primeiro",
"second" => "segundo",
"third" => "terceiro",
"fourth" => "quarto",
"fifth" => "quinto",
"last" => "último",
"by events date" => "eventos por data",
"by yearday(s)" => "por dia(s) do ano",
"by weeknumber(s)" => "por número(s) da semana",
"by day and month" => "por dia e mês",
"Date" => "Data",
"Cal." => "Cal.",
"Week" => "Semana",
"Month" => "Mês",
"List" => "Lista",
"Today" => "Hoje",
"Settings" => "Ajustes",
"Your calendars" => "Meus Calendários",
"CalDav Link" => "Link para CalDav",
"Share Calendar" => "Compartilhar Calendário",
"Download" => "Baixar",
"Edit" => "Editar",
"Delete" => "Excluir",
"New calendar" => "Novo calendário",
"Edit calendar" => "Editar calendário",
"Displayname" => "Mostrar Nome",
"Active" => "Ativo",
"Calendar color" => "Cor do Calendário",
"Save" => "Salvar",
"Submit" => "Submeter",
"Cancel" => "Cancelar",
"Edit an event" => "Editar um evento",
"Export" => "Exportar",
"Eventinfo" => "Info de Evento",
"Repeating" => "Repetindo",
"Alarm" => "Alarme",
"Attendees" => "Participantes",
"Share" => "Compartilhar",
"Title of the Event" => "Título do evento",
"Category" => "Categoria",
"Separate categories with commas" => "Separe as categorias por vírgulas",
"Edit categories" => "Editar categorias",
"Access Class" => "Classe de Acesso",
"All Day Event" => "Evento de dia inteiro",
"From" => "De",
"To" => "Para",
"Advanced options" => "Opções avançadas",
"Location" => "Local",
"Location of the Event" => "Local do evento",
"Description" => "Descrição",
"Description of the Event" => "Descrição do Evento",
"Repeat" => "Repetir",
"Advanced" => "Avançado",
"Select weekdays" => "Selecionar dias da semana",
"Select days" => "Selecionar dias",
"and the events day of year." => "e o dia do evento no ano.",
"and the events day of month." => "e o dia do evento no mês.",
"Select months" => "Selecionar meses",
"Select weeks" => "Selecionar semanas",
"and the events week of year." => "e a semana do evento no ano.",
"Interval" => "Intervalo",
"End" => "Final",
"occurrences" => "ocorrências",
"create a new calendar" => "criar um novo calendário",
"Import a calendar file" => "Importar um arquivo de calendário",
"Please choose a calendar" => "Escolha um calendário, por favor",
"Name of new calendar" => "Nome do novo calendário",
"Take an available name!" => "Use um nome disponível!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Um calendário com este nome já existe. Se de qualquer forma você continuar, estes calendários serão fundidos.",
"Remove all events from the selected calendar" => "Remover todos os eventos do calendário selecionado",
"Import" => "Importar",
"Close Dialog" => "Fechar caixa de diálogo",
"Create a new event" => "Criar um novo evento",
"Share with:" => "Compartilhar com:",
"Shared with" => "Compartilhado com",
"Unshare" => "Descompartilhar",
"Nobody" => "Ninguém",
"Shared via calendar" => "Compartilhado via calendário",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "NOTA: Ações em eventos compartilhados via calendário afetarão o compartilhamento do calendário inteiro.",
"View an event" => "Visualizar evento",
"No categories selected" => "Nenhuma categoria selecionada",
"of" => "de",
"at" => "para",
"General" => "Geral",
"Timezone" => "Fuso horário",
"Update timezone automatically" => "Atualizar fuso-horário automaticamente",
"Time format" => "Formato de tempo",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Começar semana em",
"Cache" => "Cache",
"Clear cache for repeating events" => "Apagar cache para eventos contínuos",
"URLs" => "URLs",
"Calendar CalDAV syncing addresses" => "Sincronização de endereços do calendário CalDAV",
"more info" => "mais informações",
"Primary address (Kontact et al)" => "Endereço primário (Kontact et al)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "iCalendar link(s) somente leitura"
);
